@@ -16,9 +16,13 @@ class Server:
         """This create a Server and bind it with host and ip address """
         try:
             self.s = socket.socket()
-            self.serial = serial.serial(self.usbport,9600)
         except socket.error as msg:
             print("Creation error "+msg)
+        try:
+            self.serial = serial.Serial(self.usbport,9600)
+        except:
+            print("Connect Arduino correctly")
+        
         while True:
             try:
                 self.s.bind((self.host,self.port))
